@@ -6,6 +6,8 @@ import (
 	"net/url"
 	"path/filepath"
 
+	addonv1alpha1 "github.com/open-cluster-management/api/addon/v1alpha1"
+	addonv1alpha1client "github.com/open-cluster-management/api/client/addon/clientset/versioned"
 	clusterclientset "github.com/open-cluster-management/api/client/cluster/clientset/versioned"
 	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
 	"github.com/open-cluster-management/registration/pkg/hub/managedcluster/bindata"
@@ -17,7 +19,7 @@ import (
 	"github.com/openshift/library-go/pkg/operator/resource/resourcehelper"
 	errorhelpers "github.com/openshift/library-go/pkg/operator/v1helpers"
 
-	certificatesv1beta1 "k8s.io/api/certificates/v1beta1"
+	certificatesv1 "k8s.io/api/certificates/v1"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
 	"k8s.io/apimachinery/pkg/api/equality"
@@ -90,13 +92,62 @@ func UpdateManagedClusterConditionFn(cond metav1.Condition) UpdateManagedCluster
 	}
 }
 
+type UpdateManagedClusterAddOnStatusFunc func(status *addonv1alpha1.ManagedClusterAddOnStatus) error
+
+func UpdateManagedClusterAddOnStatus(
+	ctx context.Context,
+	client addonv1alpha1client.Interface,
+	addOnNamespace, addOnName string,
+	updateFuncs ...UpdateManagedClusterAddOnStatusFunc) (*addonv1alpha1.ManagedClusterAddOnStatus, bool, error) {
+	updated := false
+	var updatedAddOnStatus *addonv1alpha1.ManagedClusterAddOnStatus
+
+	err := retry.RetryOnConflict(retry.DefaultBackoff, func() error {
+		addOn, err := client.AddonV1alpha1().ManagedClusterAddOns(addOnNamespace).Get(ctx, addOnName, metav1.GetOptions{})
+		if err != nil {
+			return err
+		}
+		oldStatus := &addOn.Status
+
+		newStatus := oldStatus.DeepCopy()
+		for _, update := range updateFuncs {
+			if err := update(newStatus); err != nil {
+				return err
+			}
+		}
+		if equality.Semantic.DeepEqual(oldStatus, newStatus) {
+			// We return the newStatus which is a deep copy of oldStatus but with all update funcs applied.
+			updatedAddOnStatus = newStatus
+			return nil
+		}
+
+		addOn.Status = *newStatus
+		updatedAddOn, err := client.AddonV1alpha1().ManagedClusterAddOns(addOnNamespace).UpdateStatus(ctx, addOn, metav1.UpdateOptions{})
+		if err != nil {
+			return err
+		}
+		updatedAddOnStatus = &updatedAddOn.Status
+		updated = err == nil
+		return err
+	})
+
+	return updatedAddOnStatus, updated, err
+}
+
+func UpdateManagedClusterAddOnStatusFn(cond metav1.Condition) UpdateManagedClusterAddOnStatusFunc {
+	return func(oldStatus *addonv1alpha1.ManagedClusterAddOnStatus) error {
+		meta.SetStatusCondition(&oldStatus.Conditions, cond)
+		return nil
+	}
+}
+
 // Check whether a CSR is in terminal state
-func IsCSRInTerminalState(status *certificatesv1beta1.CertificateSigningRequestStatus) bool {
+func IsCSRInTerminalState(status *certificatesv1.CertificateSigningRequestStatus) bool {
 	for _, c := range status.Conditions {
-		if c.Type == certificatesv1beta1.CertificateApproved {
+		if c.Type == certificatesv1.CertificateApproved {
 			return true
 		}
-		if c.Type == certificatesv1beta1.CertificateDenied {
+		if c.Type == certificatesv1.CertificateDenied {
 			return true
 		}
 	}
