@@ -8,7 +8,6 @@ import (
 	"crypto/x509"
 	"crypto/x509/pkix"
 	"encoding/pem"
-	"fmt"
 	"io/ioutil"
 	"math/big"
 	"math/rand"
@@ -22,7 +21,7 @@ import (
 	"github.com/openshift/library-go/pkg/operator/events"
 	"github.com/openshift/library-go/pkg/operator/events/eventstesting"
 
-	certv1beta1 "k8s.io/api/certificates/v1beta1"
+	certv1 "k8s.io/api/certificates/v1"
 	coordv1 "k8s.io/api/coordination/v1"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
@@ -102,6 +101,19 @@ func NewAvailableManagedCluster() *clusterv1.ManagedCluster {
 	return managedCluster
 }
 
+func NewUnknownManagedCluster() *clusterv1.ManagedCluster {
+	managedCluster := NewAcceptedManagedCluster()
+	availableCondtion := NewManagedClusterCondition(
+		clusterv1.ManagedClusterConditionAvailable,
+		"Unknown",
+		"ManagedClusterUnknown",
+		"Managed cluster is unknown",
+		nil,
+	)
+	managedCluster.Status.Conditions = append(managedCluster.Status.Conditions, availableCondtion)
+	return managedCluster
+}
+
 func NewJoinedManagedCluster() *clusterv1.ManagedCluster {
 	managedCluster := NewAcceptedManagedCluster()
 	joinedCondtion := NewManagedClusterCondition(
@@ -161,10 +173,10 @@ func NewManagedClusterCondition(name, status, reason, message string, lastTransi
 	return ret
 }
 
-func NewManagedClusterLease(renewTime time.Time) *coordv1.Lease {
+func NewManagedClusterLease(name string, renewTime time.Time) *coordv1.Lease {
 	return &coordv1.Lease{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      fmt.Sprintf("cluster-lease-%s", TestManagedClusterName),
+			Name:      name,
 			Namespace: TestManagedClusterName,
 		},
 		Spec: coordv1.LeaseSpec{
@@ -173,6 +185,18 @@ func NewManagedClusterLease(renewTime time.Time) *coordv1.Lease {
 	}
 }
 
+func NewAddOnLease(namespace, name string, renewTime time.Time) *coordv1.Lease {
+	return &coordv1.Lease{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      name,
+			Namespace: namespace,
+		},
+		Spec: coordv1.LeaseSpec{
+			RenewTime: &metav1.MicroTime{Time: renewTime},
+		},
+	}
+}
+
 func NewNamespace(name string, terminated bool) *corev1.Namespace {
 	namespace := &corev1.Namespace{}
 	namespace.Name = name
@@ -254,14 +278,14 @@ func NewUnstructuredObj(apiVersion, kind, namespace, name string) *unstructured.
 type CSRHolder struct {
 	Name         string
 	Labels       map[string]string
-	SignerName   *string
+	SignerName   string
 	CN           string
 	Orgs         []string
 	Username     string
 	ReqBlockType string
 }
 
-func NewCSR(holder CSRHolder) *certv1beta1.CertificateSigningRequest {
+func NewCSR(holder CSRHolder) *certv1.CertificateSigningRequest {
 	insecureRand := rand.New(rand.NewSource(0))
 	pk, err := ecdsa.GenerateKey(elliptic.P256(), insecureRand)
 	if err != nil {
@@ -279,33 +303,35 @@ func NewCSR(holder CSRHolder) *certv1beta1.CertificateSigningRequest {
 	if err != nil {
 		panic(err)
 	}
-	return &certv1beta1.CertificateSigningRequest{
+	return &certv1.CertificateSigningRequest{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:         holder.Name,
 			GenerateName: "csr-",
 			Labels:       holder.Labels,
 		},
-		Spec: certv1beta1.CertificateSigningRequestSpec{
+		Spec: certv1.CertificateSigningRequestSpec{
 			Username:   holder.Username,
-			Usages:     []certv1beta1.KeyUsage{},
+			Usages:     []certv1.KeyUsage{},
 			SignerName: holder.SignerName,
 			Request:    pem.EncodeToMemory(&pem.Block{Type: holder.ReqBlockType, Bytes: csrb}),
 		},
 	}
 }
 
-func NewDeniedCSR(holder CSRHolder) *certv1beta1.CertificateSigningRequest {
+func NewDeniedCSR(holder CSRHolder) *certv1.CertificateSigningRequest {
 	csr := NewCSR(holder)
-	csr.Status.Conditions = append(csr.Status.Conditions, certv1beta1.CertificateSigningRequestCondition{
-		Type: certv1beta1.CertificateDenied,
+	csr.Status.Conditions = append(csr.Status.Conditions, certv1.CertificateSigningRequestCondition{
+		Type:   certv1.CertificateDenied,
+		Status: corev1.ConditionTrue,
 	})
 	return csr
 }
 
-func NewApprovedCSR(holder CSRHolder) *certv1beta1.CertificateSigningRequest {
+func NewApprovedCSR(holder CSRHolder) *certv1.CertificateSigningRequest {
 	csr := NewCSR(holder)
-	csr.Status.Conditions = append(csr.Status.Conditions, certv1beta1.CertificateSigningRequestCondition{
-		Type: certv1beta1.CertificateApproved,
+	csr.Status.Conditions = append(csr.Status.Conditions, certv1.CertificateSigningRequestCondition{
+		Type:   certv1.CertificateApproved,
+		Status: corev1.ConditionTrue,
 	})
 	return csr
 }
@@ -373,7 +399,7 @@ func NewHubKubeconfigSecret(namespace, name, resourceVersion string, cert *TestC
 	return secret
 }
 
-func NewTestCert(commonName string, duration time.Duration) *TestCert {
+func NewTestCertWithSubject(subject pkix.Name, duration time.Duration) *TestCert {
 	caKey, err := rsa.GenerateKey(cryptorand.Reader, 2048)
 	if err != nil {
 		panic(err)
@@ -392,9 +418,7 @@ func NewTestCert(commonName string, duration time.Duration) *TestCert {
 	certDERBytes, err := x509.CreateCertificate(
 		cryptorand.Reader,
 		&x509.Certificate{
-			Subject: pkix.Name{
-				CommonName: commonName,
-			},
+			Subject:      subject,
 			SerialNumber: big.NewInt(1),
 			NotBefore:    caCert.NotBefore,
 			NotAfter:     time.Now().Add(duration).UTC(),
@@ -426,6 +450,12 @@ func NewTestCert(commonName string, duration time.Duration) *TestCert {
 	}
 }
 
+func NewTestCert(commonName string, duration time.Duration) *TestCert {
+	return NewTestCertWithSubject(pkix.Name{
+		CommonName: commonName,
+	}, duration)
+}
+
 func WriteFile(filename string, data []byte) {
 	if err := ioutil.WriteFile(filename, data, 0644); err != nil {
 		panic(err)
