@@ -69,7 +69,7 @@ func (c *leaseController) sync(ctx context.Context, syncCtx factory.SyncContext)
 		}
 
 		// get the lease of a cluster, if the lease is not found, create it
-		leaseName := fmt.Sprintf("cluster-lease-%s", cluster.Name)
+		leaseName := "managed-cluster-lease"
 		observedLease, err := c.leaseLister.Leases(cluster.Name).Get(leaseName)
 		switch {
 		case errors.IsNotFound(err):
@@ -106,6 +106,36 @@ func (c *leaseController) sync(ctx context.Context, syncCtx factory.SyncContext)
 			continue
 		}
 
+		// for backward compatible, before release-2.3, the format of lease name is cluster-lease-<managed-cluster-name>
+		// TODO: after release-2.3, we will eliminate these
+		oldVersionLeaseName := fmt.Sprintf("cluster-lease-%s", cluster.Name)
+		oldVersionLease, err := c.leaseLister.Leases(cluster.Name).Get(oldVersionLeaseName)
+		switch {
+		case err == nil:
+			if time.Now().Before(oldVersionLease.Spec.RenewTime.Add(gracePeriod)) {
+				continue
+			}
+		case errors.IsNotFound(err):
+			// the old version does not exist, create a new one
+			oldVersionLease := &coordv1.Lease{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      oldVersionLeaseName,
+					Namespace: cluster.Name,
+					Labels:    map[string]string{"open-cluster-management.io/cluster-name": cluster.Name},
+				},
+				Spec: coordv1.LeaseSpec{
+					HolderIdentity: pointer.StringPtr(oldVersionLeaseName),
+					RenewTime:      &metav1.MicroTime{Time: time.Now()},
+				},
+			}
+			if _, err := c.kubeClient.CoordinationV1().Leases(cluster.Name).Create(ctx, oldVersionLease, metav1.CreateOptions{}); err != nil {
+				return err
+			}
+			continue
+		case err != nil:
+			return err
+		}
+
 		// the lease is not constantly updated, update it to unknown
 		conditionUpdateFn := helpers.UpdateManagedClusterConditionFn(metav1.Condition{
 			Type:    clusterv1.ManagedClusterConditionAvailable,
